@@ -3,9 +3,15 @@ from pathlib import Path
 from typing import List, Optional
 
 import click
-from robotcode.core.logging import LoggingDescriptor
+
 from robotcode.core.utils.cli import show_hidden_arguments
-from robotcode.plugin import Application, ColoredOutput, OutputFormat, pass_application
+from robotcode.core.utils.logging import LoggingDescriptor
+from robotcode.plugin import (
+    Application,
+    ColoredOutput,
+    OutputFormat,
+    pass_application,
+)
 from robotcode.plugin.click_helper.aliases import AliasedGroup
 from robotcode.plugin.click_helper.types import EnumChoice
 from robotcode.plugin.manager import PluginManager
@@ -52,7 +58,13 @@ from .commands import config, profiles
     help="Set the output format.",
     show_default=True,
 )
-@click.option("-d", "--dry", is_flag=True, show_envvar=True, help="Dry run, do not execute any commands.")
+@click.option(
+    "-d",
+    "--dry",
+    is_flag=True,
+    show_envvar=True,
+    help="Dry run, do not execute any commands.",
+)
 @click.option(
     "--color / --no-color",
     "color",
@@ -74,12 +86,7 @@ from .commands import config, profiles
     help="Enables verbose mode.",
     show_envvar=True,
 )
-@click.option(
-    "--log",
-    is_flag=True,
-    help="Enables logging.",
-    show_envvar=True,
-)
+@click.option("--log", is_flag=True, help="Enables logging.", show_envvar=True)
 @click.option(
     "--log-level",
     type=click.Choice(["TRACE", "DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]),
@@ -88,6 +95,20 @@ from .commands import config, profiles
     show_default=True,
     show_envvar=True,
 )
+@click.option(
+    "--log-filename",
+    type=click.Path(
+        file_okay=True,
+        dir_okay=False,
+        writable=True,
+        exists=False,
+        path_type=str,
+    ),
+    help="Write log output to a file instead to console.",
+    default=None,
+    show_default=True,
+    show_envvar=True,
+)
 @click.option(
     "--log-calls",
     is_flag=True,
@@ -113,6 +134,7 @@ from .commands import config, profiles
     "--debugpy",
     is_flag=True,
     hidden=show_hidden_arguments(),
+    show_envvar=True,
     help="Starts a debugpy session. "
     "**This is an internal option and should only be use if you want to debug _RobotCode_.**",
 )
@@ -121,6 +143,7 @@ from .commands import config, profiles
     type=int,
     default=5678,
     show_default=True,
+    show_envvar=True,
     hidden=show_hidden_arguments(),
     help="Defines the port to use for the debugpy session.",
 )
@@ -128,6 +151,7 @@ from .commands import config, profiles
     "--debugpy-wait-for-client",
     is_flag=True,
     hidden=show_hidden_arguments(),
+    show_envvar=True,
     help="Waits for a debugpy client to connect before starting the debugpy session.",
 )
 @click.version_option(version=__version__, prog_name="robotcode")
@@ -143,6 +167,7 @@ def robotcode(
     pager: Optional[bool],
     log: bool,
     log_level: str,
+    log_filename: Optional[str],
     log_calls: bool,
     default_path: Optional[List[str]],
     launcher_script: Optional[str] = None,
@@ -175,15 +200,25 @@ def robotcode(
     app.config.output_format = format
     app.config.launcher_script = launcher_script
     app.config.default_paths = default_path
+    app.config.log_enabled = log
+    app.config.log_level = log_level
+    app.config.log_calls = log_calls
 
     if log:
         if log_calls:
             LoggingDescriptor.set_call_tracing(True)
 
-        logging.basicConfig(level=log_level, format="%(name)s:%(levelname)s: %(message)s")
+        logging.basicConfig(
+            level=log_level,
+            format="%(name)s:%(levelname)s: %(message)s",
+            filename=log_filename,
+        )
 
     if debugpy:
-        from robotcode.core.utils.debugpy import start_debugpy, wait_for_debugpy_connected
+        from robotcode.core.utils.debugpy import (
+            start_debugpy,
+            wait_for_debugpy_connected,
+        )
 
         app.verbose(f"Try to start a debugpy session on port {debugpy_port}")
 
